@@ -72,6 +72,9 @@
 
 import ogAST
 
+import logging
+LOG = logging.getLogger(__name__)
+
 # reference to the ASN.1 Data view and to the process variables
 TYPES = None
 VARIABLES = None
@@ -107,7 +110,7 @@ def get_type_of_parent(identifier):
             current_type = TYPES[name]['type']
             for index in range(1, len(identifier)):
                 # TODO find type...
-                print '** INCOMPLETE FEATURE ** '
+                LOG.warning('** INCOMPLETE FEATURE ** ')
             kind = current_type['Kind']
     return kind, name
 
@@ -141,9 +144,10 @@ def write_statement(param, newline):
             cast = 'Boolean'
         string = "{cast}'Image({s})".format(cast=cast, s=string)
     else:
-        print('[ERROR] Unsupported parameter in write call' +
+        error = ('Unsupported parameter in write call' +
                 param.var.inputString)
-        return code, string, local
+        LOG.error(error)
+        raise TypeError(error)
     code.append('Put{line}({string});'.format(
         line='_Line' if newline else '',
         string=string))
@@ -158,18 +162,18 @@ def output_statement(output):
     # Add the traceability information
     code.extend(traceability(output))
 
-    for o in output.output:
-        signal_name = o['outputName']
+    for out in output.output:
+        signal_name = out['outputName']
 
         if signal_name.lower() in ('write', 'writeln'):
             # special built-in SDL procedure for printing strings
             # supports printing of native types (int, real, bool)
             # but not yet complex ASN.1 structures (sequence/seqof/choice)
-            for param in o['params'][:-1]:
+            for param in out['params'][:-1]:
                 stmts, _, local = write_statement(param, newline=False)
                 code.extend(stmts)
                 local_decl.extend(local)
-            for param in o['params'][-1:]:
+            for param in out['params'][-1:]:
                 # Last parameter - add newline if necessary
                 stmts, _, local = write_statement(param, newline=True if
                         signal_name.lower() == 'writeln' else False)
@@ -181,50 +185,50 @@ def output_statement(output):
         else:
             out_sig = PROCEDURES.get(signal_name.lower())
         if not out_sig:
-            print '[ERROR] Signal or procedure not defined:', signal_name
-            return [], []
+            error = 'Signal or procedure not defined:' + str(signal_name)
+            LOG.error(error)
+            raise NameError(error)
         nb_in_params = len(out_sig['paramsInOrdered'])
-        listofParams = []
-        for idx, p in enumerate(o.get('params') or []):
+        list_of_params = []
+        for idx, param in enumerate(out.get('params') or []):
             # Determine if it is an IN or OUT type
             select = ('paramsOutOrdered', 'out', idx - nb_in_params) if (
                     idx >= nb_in_params) else ('paramsInOrdered', 'in', idx)
 
             # Get parameter name and type from the Interface view:
-            paramName = out_sig[select[0]][select[2]]
-            paramType = out_sig[select[1]][paramName]['type']
+            param_name = out_sig[select[0]][select[2]]
+            param_type = out_sig[select[1]][param_name]['type']
 
             # Check the type of the parameter - set it if missing
             # (TODO: do it in the parser)
-            if p.exprType.get('Kind') == 'UnknownType':
-                p.exprType = {'Kind': 'ReferenceType',
-                        'ReferencedTypeName': paramType}
+            if param.exprType.get('Kind') == 'UnknownType':
+                param.exprType = {'Kind': 'ReferenceType',
+                        'ReferencedTypeName': param_type}
 
-            pCode, pId, pLocal = decipher_expression(p)
-            code.extend(pCode)
-            local_decl.extend(pLocal)
+            p_code, p_id, p_local = decipher_expression(param)
+            code.extend(p_code)
+            local_decl.extend(p_local)
             # Create a temporary variable for this parameter
-            tmpId = o['tmpVars'][idx]
-            # print tmpId, paramName, paramType
+            tmp_id = out['tmpVars'][idx]
             local_decl.append('tmp{idx} : aliased asn1Scc{oType};'.format(
-                idx=tmpId, oType=paramType))
-            code.append('tmp{idx} := {pId};'.format(
-                idx=tmpId, pId=pId))
-            listofParams.append("tmp{idx}'access".
-                    format(idx=o['tmpVars'][idx]))
-        if listofParams:
+                idx=tmp_id, oType=param_type))
+            code.append('tmp{idx} := {p_id};'.format(
+                idx=tmp_id, p_id=p_id))
+            list_of_params.append("tmp{idx}'access".
+                    format(idx=out['tmpVars'][idx]))
+        if list_of_params:
             code.append('{RI}({params});'.format(
-                RI=o['outputName'], params=', '.join(listofParams)))
+                RI=out['outputName'], params=', '.join(list_of_params)))
             # Assign back the out parameters to the local variables
             if len(out_sig['paramsOutOrdered']) > 0:
-                for (idx, p) in ((idx, p)
-                        for idx, p in enumerate(o['params'])
+                for (idx, parameter) in ((idx, p)
+                        for idx, p in enumerate(out['params'])
                         if idx >= nb_in_params):
-                    _, pId, __ = decipher_expression(p)
-                    code.append('{pId} := tmp{idx};'.format(
-                        pId=pId, idx=o['tmpVars'][idx]))
+                    _, p_id, __ = decipher_expression(parameter)
+                    code.append('{p_id} := tmp{idx};'.format(
+                        p_id=p_id, idx=out['tmpVars'][idx]))
         else:
-            code.append('{RI};'.format(RI=o['outputName']))
+            code.append('{RI};'.format(RI=out['outputName']))
     return code, local_decl
 
 
@@ -237,8 +241,8 @@ def task_statement(task):
         code.extend(traceability(task.comment))
     if task.kind == 'informal_text':
         # Generate Ada comments for informal text
-        for t in task.informalText:
-            code.append('--  ' + t.replace('\n', '\n' + '--  '))
+        for informal_task in task.informalText:
+            code.append('--  ' + informal_task.replace('\n', '\n' + '--  '))
     elif task.kind == 'assign':
         for expr in task.assign:
             # There can be several assignations in one task
@@ -253,12 +257,12 @@ def task_statement(task):
             # Get the Ada string for the left part of the expression
             left_stmts, left_str, left_local = decipher_expression(dest)
             right_stmts, right_str, right_local = decipher_expression(val)
-            assignStr = left_str + ' := ' + right_str + ';'
+            assign_str = left_str + ' := ' + right_str + ';'
             code.extend(left_stmts)
             code.extend(right_stmts)
             local_decl.extend(left_local)
             local_decl.extend(right_local)
-            code.append(assignStr)
+            code.append(assign_str)
     else:
         raise ValueError('task kind is unknown: ' + task.kind)
     return code, local_decl
@@ -277,7 +281,7 @@ def decipher_primary_id(primaryId):
     # a(Expression) => a(ExpressionSolver) (array index)
     # Expression can be complex (if-then-else-fi..)
     sep = 'l_'
-    subId = []
+    sub_id = []
     for pr_id in primaryId:
         if type(pr_id) is not dict:
             if pr_id.lower() == 'length':
@@ -287,11 +291,11 @@ def decipher_primary_id(primaryId):
                 special_op = 'ChoiceKind'
                 continue
             special_op = ''
-            subId.append(pr_id)
-            parentKind, parentTypeName = get_type_of_parent(subId)
-            if parentKind == 'ChoiceType':
-                ada_string = ('asn1Scc{typename}_{pid}_get({ada_string})'
-                        .format(typename=parentTypeName, pid=pr_id,
+            sub_id.append(pr_id)
+            parent_kind, parent_typename = get_type_of_parent(sub_id)
+            if parent_kind == 'ChoiceType':
+                ada_string = ('asn1Scc{typename}_{p_id}_get({ada_string})'
+                        .format(typename=parent_typename, p_id=pr_id,
                         ada_string=ada_string))
             else:
                 ada_string += sep + pr_id
@@ -299,7 +303,7 @@ def decipher_primary_id(primaryId):
             # index is a LIST - only taking 1st elem.
             if 'index' in pr_id:
                 if len(pr_id['index']) > 1:
-                    print('[WARNING] multiple index not supported')
+                    LOG.warning('Multiple index not supported')
                 idx_stmts, idx_string, local_var = decipher_expression(
                         pr_id['index'][0])
                 if unicode.isnumeric(idx_string):
@@ -314,22 +318,22 @@ def decipher_primary_id(primaryId):
                     # Length of sequence of: take only the first parameter
                     exp, = pr_id['procParams']
                     exp_type = find_basic_type(exp.exprType)
-                    minLength = exp_type.get('Min')
-                    maxLength = exp_type.get('Max')
-                    if minLength is None or maxLength is None:
-                        print('[ERROR] Expression {e} is not a SEQUENCE OF'
-                                .format(e=exp.inputString))
-                        # TODO: raise exception
-                        break
-                    param_stmts, paramString, local_var = decipher_expression(
+                    min_length = exp_type.get('Min')
+                    max_length = exp_type.get('Max')
+                    if min_length is None or max_length is None:
+                        error = '{} is not a SEQUENCE OF'.format(
+                                exp.inputString)
+                        LOG.error(error)
+                        raise TypeError(error)
+                    param_stmts, param_str, local_var = decipher_expression(
                             exp)
                     stmts.extend(param_stmts)
                     local_decl.extend(local_var)
-                    if minLength == maxLength:
-                        ada_string += minLength
+                    if min_length == max_length:
+                        ada_string += min_length
                     else:
                         ada_string += ('Interfaces.Integer_64({e}.Length)'
-                                .format(e=paramString))
+                                .format(e=param_str))
                 elif special_op == 'ChoiceKind':
                     # User wants to know what CHOICE element is present
                     exp, = pr_id['procParams']
@@ -341,27 +345,26 @@ def decipher_primary_id(primaryId):
                     exp_typename = (exp.exprType.get('ReferencedTypeName') or
                             exp.exprType['Kind'])
                     if exp_type['Kind'] != 'ChoiceType':
-                        print('[ERROR] {e} is not a CHOICE'
-                                .format(e=exp.inputString))
-                        break
-                        # TODO raise exception rather than a print
-                    param_stmts, paramString, local_var = decipher_expression(
+                        error = '{} is not a CHOICE'.format(exp.inputString)
+                        LOG.error(error)
+                        raise TypeError(error)
+                    param_stmts, param_str, local_var = decipher_expression(
                             exp)
                     stmts.extend(param_stmts)
                     local_decl.extend(local_var)
                     ada_string += ('asn1Scc{t}_Kind({e})'.format(
-                        t=exp_typename, e=paramString))
+                        t=exp_typename, e=param_str))
                 else:
                     ada_string += '('
                     # Take all params and join them with commas
-                    listOfParams = []
-                    for p in pr_id['procParams']:
-                        param_stmt, paramString, local_var = (
-                                decipher_expression(p))
-                        listOfParams.append(paramString)
+                    list_of_params = []
+                    for param in pr_id['procParams']:
+                        param_stmt, param_str, local_var = (
+                                decipher_expression(param))
+                        list_of_params.append(param_str)
                         stmts.extend(param_stmt)
                         local_decl.extend(local_var)
-                    ada_string += ', '.join(listOfParams)
+                    ada_string += ', '.join(list_of_params)
                     ada_string += ')'
         sep = '.'
     return stmts, ada_string, local_decl
@@ -375,7 +378,6 @@ def decipher_expression(expr):
     if expr.kind == 'primary':
         if (expr.var.primType == None
                 or expr.var.primType['Kind'] != 'ReferenceType'):
-            #print 'We set this:', expr.exprType
             # Populate the expression type to the field if it was not set
             # It can be the case if the type definition is embedded
             # in a SEQUENCE - in that case the ASN.1 compiler creates an
@@ -456,22 +458,22 @@ def decipher_if_then_else(ifThenElse, resType):
     local_decl = ['tmp{idx} : asn1Scc{resType};'.format(
         idx=ifThenElse['tmpVar'], resType=resType.get('ReferencedTypeName') or
         'ERROR!')]
-    if_stmts, ifString, ifLocal = decipher_expression(ifThenElse['if'])
-    then_stmts, thenString, thenLocal = decipher_expression(ifThenElse['then'])
-    else_stmts, elseString, elseLocal = decipher_expression(ifThenElse['else'])
+    if_stmts, if_str, if_local = decipher_expression(ifThenElse['if'])
+    then_stmts, then_str, then_local = decipher_expression(ifThenElse['then'])
+    else_stmts, else_str, else_local = decipher_expression(ifThenElse['else'])
     stmts.extend(if_stmts)
     stmts.extend(then_stmts)
     stmts.extend(else_stmts)
-    local_decl.extend(ifLocal)
-    local_decl.extend(thenLocal)
-    local_decl.extend(elseLocal)
-    stmts.append('if {ifString} then'.format(
-        ifString=ifString))
-    stmts.append('tmp{idx} := {thenString};'.format(
-        idx=ifThenElse['tmpVar'], thenString=thenString))
+    local_decl.extend(if_local)
+    local_decl.extend(then_local)
+    local_decl.extend(else_local)
+    stmts.append('if {if_str} then'.format(
+        if_str=if_str))
+    stmts.append('tmp{idx} := {then_str};'.format(
+        idx=ifThenElse['tmpVar'], then_str=then_str))
     stmts.append('else')
-    stmts.append('tmp{idx} := {elseString};'.format(
-        idx=ifThenElse['tmpVar'], elseString=elseString))
+    stmts.append('tmp{idx} := {else_str};'.format(
+        idx=ifThenElse['tmpVar'], else_str=else_str))
     stmts.append('end if;')
     ada_string = 'tmp{idx}'.format(idx=ifThenElse['tmpVar'])
     return stmts, ada_string, local_decl
@@ -479,7 +481,7 @@ def decipher_if_then_else(ifThenElse, resType):
 
 def decipher_sequence(seq, seqType):
     ''' Return Ada string for an ASN.1 SEQUENCE '''
-    #print '[DEBUG] Sequence:', seq, seqType
+    LOG.debug('Sequence: ' + str(seq) + str(seqType))
     ada_string = 'asn1Scc{seqType}\'('.format(
             seqType=seqType['ReferencedTypeName'])
     stmts = []
@@ -493,8 +495,8 @@ def decipher_sequence(seq, seqType):
             value.exprType['Kind'] = 'ReferenceType'
             value.exprType['ReferencedTypeName'] = '{thisType}_{elem}'.format(
                     thisType=seqType['ReferencedTypeName'], elem=elem)
-        value_stmts, valueStr, local_var = decipher_expression(value)
-        ada_string += sep + elem + ' => ' + valueStr
+        value_stmts, value_str, local_var = decipher_expression(value)
+        ada_string += sep + elem + ' => ' + value_str
         sep = ', '
         stmts.extend(value_stmts)
         local_decl.extend(local_var)
@@ -507,12 +509,12 @@ def decipher_sequence_of(seqof, seqofType):
     stmts = []
     local_decl = []
     typename = seqofType.get('ReferencedTypeName')
-    #print '[DEBUG] SequenceOf Typename:', typename
-    asnType = TYPES[typename]['type']
-    minSize = asnType['Min']
-    maxSize = asnType['Max']
+    LOG.debug('SequenceOf Typename:' + str(typename))
+    asn_type = TYPES[typename]['type']
+    min_size = asn_type['Min']
+    max_size = asn_type['Max']
     ada_string = 'asn1Scc{seqofType}\'('.format(seqofType=typename)
-    if minSize == maxSize:
+    if min_size == max_size:
         # Fixed-length array - no need to set the Length field
         ada_string += 'Data => asn1Scc{seqofType}_array\'('.format(
                 seqofType=typename)
@@ -528,11 +530,11 @@ def decipher_sequence_of(seqof, seqofType):
             seqof[i].primType = {'Kind': 'ReferenceType',
                     'ReferencedTypeName': '{baseType}_elm'.
                     format(baseType=typename)}
-        item_stmts, itemStr, local_var = decipher_primary(seqof[i])
+        item_stmts, item_str, local_var = decipher_primary(seqof[i])
         stmts.extend(item_stmts)
         local_decl.extend(local_var)
-        ada_string += '{i} => {value}, '.format(i=i + 1, value=itemStr)
-    ada_string += 'others => {anyVal}))'.format(anyVal=itemStr)
+        ada_string += '{i} => {value}, '.format(i=i + 1, value=item_str)
+    ada_string += 'others => {anyVal}))'.format(anyVal=item_str)
     return stmts, ada_string, local_decl
 
 
@@ -545,12 +547,12 @@ def decipher_choice(choice, choiceType):
                     baseType=choiceType.get('ReferencedTypeName'),
                     choiceValue=choice['choice'])}
 
-    stmts, choiceStr, local_decl = decipher_expression(choice['value'])
+    stmts, choice_str, local_decl = decipher_expression(choice['value'])
 
     ada_string = 'asn1Scc{cType}_{opt}_set({expr})'.format(
             cType=choiceType.get('ReferencedTypeName') or choiceType['Kind'],
             opt=choice['choice'],
-            expr=choiceStr)
+            expr=choice_str)
     return stmts, ada_string, local_decl
 
 
@@ -558,11 +560,11 @@ def decision_statement(dec):
     ''' generate the code for a decision '''
     code = []
     local_decl = []
-    questionType = dec.question.exprType
+    question_type = dec.question.exprType
     # Here is how to get properly the type (except when embedded in a sequence)
     # TODO fix the FIXMEs with that pattern:
-    actual_type = questionType.get(
-            'ReferencedTypeName') or questionType['Kind']
+    actual_type = question_type.get(
+            'ReferencedTypeName') or question_type['Kind']
     actual_type = actual_type.replace('-', '_')
     basic = False
     if actual_type in ('IntegerType', 'BooleanType',
@@ -573,38 +575,38 @@ def decision_statement(dec):
     if not basic:
         local_decl.append('tmp{idx} : asn1Scc{actType};'.format(
             idx=dec.tmpVar, actType=actual_type))
-    q_stmts, qStr, qDecl = decipher_expression(dec.question)
+    q_stmts, q_str, q_decl = decipher_expression(dec.question)
     # Add code-to-model traceability
     code.extend(traceability(dec))
-    local_decl.extend(qDecl)
+    local_decl.extend(q_decl)
     code.extend(q_stmts)
     if not basic:
-        code.append('tmp{idx} := {q};'.format(idx=dec.tmpVar, q=qStr))
+        code.append('tmp{idx} := {q};'.format(idx=dec.tmpVar, q=q_str))
     sep = 'if '
     for a in dec.answers:
         if a.kind == 'constant':
             a.kind = 'open_range'
             a.openRangeOp = 'eq'
         if a.kind == 'open_range' and a.transition:
-            ans_stmts, ansStr, ansDecl = decipher_expression(a.constant)
+            ans_stmts, ans_str, ans_decl = decipher_expression(a.constant)
             code.extend(ans_stmts)
-            local_decl.extend(ansDecl)
+            local_decl.extend(ans_decl)
             if not basic:
                 if a.openRangeOp in ('eq', 'neq'):
                     exp = 'asn1Scc{actType}_Equal(tmp{idx}, {ans})'.format(
-                            actType=actual_type, idx=dec.tmpVar, ans=ansStr)
+                            actType=actual_type, idx=dec.tmpVar, ans=ans_str)
                     if a.openRangeOp == 'neq':
                         exp = 'not ' + exp
                 else:
                     exp = 'tmp{idx} {op} {ans}'.format(idx=dec.tmpVar,
-                            op=OPERANDS[a.openRangeOp], ans=ansStr)
+                            op=OPERANDS[a.openRangeOp], ans=ans_str)
             else:
-                exp = '{q} {op} {ans}'.format(q=qStr,
-                        op=OPERANDS[a.openRangeOp], ans=ansStr)
+                exp = '{q} {op} {ans}'.format(q=q_str,
+                        op=OPERANDS[a.openRangeOp], ans=ans_str)
             code.append(sep + exp + ' then')
-            stmt, trDecl = transition(a.transition)
+            stmt, tr_decl = transition(a.transition)
             code.extend(stmt)
-            local_decl.extend(trDecl)
+            local_decl.extend(tr_decl)
             sep = 'elsif '
         elif a.kind == 'close_range' and a.transition:
             sep = 'elsif '
@@ -613,16 +615,15 @@ def decision_statement(dec):
             continue
         elif a.kind == 'else' and a.transition:
             # Keep the ELSE statement for the end
-            elseCode, elseDecl = transition(a.transition)
-            local_decl.extend(elseDecl)
+            else_code, else_decl = transition(a.transition)
+            local_decl.extend(else_decl)
     try:
         if sep != 'if ':
             # If there is at least one 'if' branch
-            # elseCode = ['    ' + c for c in elseCode]
-            elseCode.insert(0, 'else')
-            code.extend(elseCode)
+            else_code.insert(0, 'else')
+            code.extend(else_code)
         else:
-            code.extend(elseCode)
+            code.extend(else_code)
     except:
         pass
     if sep != 'if ':
@@ -690,7 +691,7 @@ def format_ada_code(stmts):
 
 def generate(process):
     ''' Generate Ada code '''
-    processName = process.processName
+    process_name = process.processName
     global VARIABLES
     VARIABLES = process.variables
     global TYPES
@@ -702,41 +703,41 @@ def generate(process):
             process.outputSignals.viewitems()}
     PROCEDURES = {p.lower(): defn for p, defn in
             process.procedures.viewitems()}
-    fileName = processName + ".adb"
-    print 'Generating Ada code for process', processName
+    filename = process_name + ".adb"
+    LOG.info('Generating Ada code for process' + str(process_name))
 
     # Generate the code to declare process-level variables
-    processLevelDecl = []
-    for varName, varType in VARIABLES.iteritems():
-        processLevelDecl.append('l_{n} : asn1Scc{t};'.format(
-            n=varName, t=varType))
+    process_level_decl = []
+    for var_name, var_type in VARIABLES.iteritems():
+        process_level_decl.append('l_{n} : asn1Scc{t};'.format(
+            n=var_name, t=var_type))
 
     # Add the process states list to the process-level variables
-    statesDecl = 'type states is ('
-    statesDecl += ', '.join(process.mapping.iterkeys()) + ');'
-    processLevelDecl.append(statesDecl)
-    processLevelDecl.append('state : states := START;')
+    states_decl = 'type states is ('
+    states_decl += ', '.join(process.mapping.iterkeys()) + ');'
+    process_level_decl.append(states_decl)
+    process_level_decl.append('state : states := START;')
 
     # Add the declaration of the runTransition procedure
-    processLevelDecl.append('procedure runTransition(trId: Integer);')
+    process_level_decl.append('procedure runTransition(trId: Integer);')
 
     # Generate the code of the start transition:
-    startTransition = ['begin']
-    startTransition.append('runTransition(0);')
+    start_transition = ['begin']
+    start_transition.append('runTransition(0);')
 
     mapping = {}
     # Generate the code for the transitions in a mapping input-state
-    for inputSignal in process.inputSignals.viewkeys():
-        mapping[inputSignal] = {}
-        for stateName, inputSymbols in process.mapping.viewitems():
-            if stateName != 'START':
-                for i in inputSymbols:
-                    if inputSignal.lower() in (inp.lower() for
+    for input_signal in process.inputSignals.viewkeys():
+        mapping[input_signal] = {}
+        for state_name, input_symbols in process.mapping.viewitems():
+            if state_name != 'START':
+                for i in input_symbols:
+                    if input_signal.lower() in (inp.lower() for
                                                inp in i.inputlist):
-                        mapping[inputSignal][stateName] = i
+                        mapping[input_signal][state_name] = i
 
     # Generate the TASTE template
-    asn1Modules = '\n'.join(['with {dv};\nuse {dv};'.format(
+    asn1_modules = '\n'.join(['with {dv};\nuse {dv};'.format(
         dv=dv.replace('-', '_'))
         for dv in process.asn1Modules])
     taste_template = ['''with System.IO;
@@ -750,22 +751,22 @@ use adaasn1rtl;
 with Interfaces;
 use Interfaces;
 
-package body {processName} is'''.format(processName=processName,
-    dataview=asn1Modules)]
+package body {process_name} is'''.format(process_name=process_name,
+    dataview=asn1_modules)]
 
     # Generate the code for the process-level variable declarations
-    taste_template.extend(processLevelDecl)
+    taste_template.extend(process_level_decl)
 
     # Generate the code for each input signal (provided interface)
-    for sName, sDef in process.inputSignals.viewitems():
-        if sName == 'START':
+    for sig_name, sig_def in process.inputSignals.viewitems():
+        if sig_name == 'START':
             continue
-        pi_header = 'procedure {sName}'.format(sName=sName)
-        if sDef['in']:
-            paramName = sDef['in'].keys()[0]
+        pi_header = 'procedure {sig_name}'.format(sig_name=sig_name)
+        if sig_def['in']:
+            param_name = sig_def['in'].keys()[0]
             # Add PI parameter (only one is possible in TASTE PI)
             pi_header += '({pName}: access asn1Scc{pType})'.format(
-                    pName=paramName, pType=sDef['in'][paramName]['type'])
+                    pName=param_name, pType=sig_def['in'][param_name]['type'])
         pi_header += ' is'
         taste_template.append(pi_header)
         taste_template.append('begin')
@@ -774,17 +775,17 @@ package body {processName} is'''.format(processName=processName,
             if state == 'START':
                 continue
             taste_template.append('when {state} =>'.format(state=state))
-            inputDef = mapping[sName].get(state)
-            if inputDef:
-                for inp in inputDef.parameters:
+            input_def = mapping[sig_name].get(state)
+            if input_def:
+                for inp in input_def.parameters:
                     # Assign the (optional and unique) parameter
                     # to the corresponding process variable
                     taste_template.append('l_{inp} := {tInp}.all;'.format(
-                        inp=inp, tInp=sDef['in'].keys()[0]))
+                        inp=inp, tInp=sig_def['in'].keys()[0]))
                 # Execute the correponding transition
-                if inputDef.transition:
+                if input_def.transition:
                     taste_template.append('runTransition({t});'.format(
-                        t=inputDef.inputlist[sName]))
+                        t=input_def.inputlist[sig_name]))
                 else:
                     taste_template.append('null;')
             else:
@@ -792,29 +793,29 @@ package body {processName} is'''.format(processName=processName,
         taste_template.append('when others =>')
         taste_template.append('null;')
         taste_template.append('end case;')
-        taste_template.append('end {sName};'.format(sName=sName))
+        taste_template.append('end {sig_name};'.format(sig_name=sig_name))
         taste_template.append('\n')
 
     taste_template.append('procedure runTransition(trId: Integer) is')
 
     # Generate the code for all transitions
-    codeTransitions = []
-    local_declTransitions = []
-    for t in process.transitions:
-        codeTr, trLocalDecl = transition(t)
-        codeTransitions.append(codeTr)
-        local_declTransitions.extend(trLocalDecl)
+    code_transitions = []
+    local_decl_transitions = []
+    for proc_tr in process.transitions:
+        code_tr, tr_local_decl = transition(proc_tr)
+        code_transitions.append(code_tr)
+        local_decl_transitions.extend(tr_local_decl)
 
     # Declare the local variables needed by the transitions in the template
     decl = ['{line}'.format(line=l)
-            for l in local_declTransitions]
+            for l in local_decl_transitions]
     taste_template.extend(decl)
     taste_template.append('begin')
 
     # Generate the switch-case on the transition id
     taste_template.append('case trId is')
 
-    for idx, val in enumerate(codeTransitions):
+    for idx, val in enumerate(code_transitions):
         taste_template.append('when {idx} =>'.format(idx=idx))
         val = ['{line}'.format(line=l) for l in val]
         if val:
@@ -829,8 +830,9 @@ package body {processName} is'''.format(processName=processName,
     taste_template.append('end runTransition;')
     taste_template.append('\n')
 
-    taste_template.extend(startTransition)
-    taste_template.append('end {processName};'.format(processName=processName))
+    taste_template.extend(start_transition)
+    taste_template.append('end {process_name};'
+            .format(process_name=process_name))
 
-    with open(fileName, 'w') as f:
-        f.write('\n'.join(format_ada_code(taste_template)))
+    with open(filename, 'w') as ada_file:
+        ada_file.write('\n'.join(format_ada_code(taste_template)))
