@@ -34,8 +34,11 @@
     Contact: maxime.perrotin@esa.int
 """
 
+import logging
+LOG = logging.getLogger(__name__)
 
-class Expression:
+
+class Expression(object):
     ''' AST Entry for expressions '''
     def __init__(self, inputString, line, charPositionInLine):
         ''' Initialize Expression attributes '''
@@ -60,7 +63,7 @@ class Expression:
                 k=self.kind.upper(), l=self.line, c=self.charPositionInLine)
 
 
-class Primary:
+class Primary(object):
     ''' AST entry for a primary construction '''
     def __init__(self, inputString, line, charPositionInLine):
         ''' Initialize primary attributes (see comments below for details) '''
@@ -113,16 +116,18 @@ class Primary:
                 k=self.kind, l=self.line, c=self.charPositionInLine)
 
 
-class Decision:
+class Decision(object):
     ''' AST Entry for a decision '''
     def __init__(self):
         ''' A DECISION statement '''
         self.inputString = 'Switch'
         self.line = None
         self.charPositionInLine = None
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 70]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 70
+        self.abs_x, self.abs_y = None, None
         # kind can be 'any', 'informal_text', or 'question'
         self.kind = None
         # question is an Expression
@@ -144,16 +149,18 @@ class Decision:
                 l=self.line, c=self.charPositionInLine)
 
 
-class Answer:
+class Answer(object):
     ''' AST Entry for a decision answer '''
     def __init__(self):
         ''' One ANSWER of a DECISION '''
         self.inputString = 'case'
         self.line = None
         self.charPositionInLine = None
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 35]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 35
+        self.abs_x, self.abs_y = None, None
         # one of 'closed_range' 'constant' 'open_range' 'else' 'informal_text'
         self.kind = None
         # informalText is a string, when kind == 'informal_text'
@@ -178,16 +185,18 @@ class Answer:
                 l=self.line, c=self.charPositionInLine)
 
 
-class Task:
+class Task(object):
     ''' AST Entry for TASKS '''
     def __init__(self):
         ''' Initialize TASK attributes (set of ASSIGN statements) '''
         self.inputString = 'foo := 42'
         self.line = None
         self.charPositionInLine = None
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         # one of 'informal_text', 'assign'
         self.kind = None
         # list of 'assign'-kind Expression
@@ -205,14 +214,16 @@ class Task:
                 l=self.line, c=self.charPositionInLine)
 
 
-class Output:
+class Output(object):
     ''' AST Entry for OUTPUT statements '''
     def __init__(self, defName='msgOut'):
         ''' Set of OUTPUT statements '''
         self.inputString = defName
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         self.line = None
         self.charPositionInLine = None
         # one of 'procedure_call', 'output'
@@ -230,14 +241,16 @@ class Output:
                 kind=self.kind.upper(), l=self.line, c=self.charPositionInLine)
 
 
-class Terminator:
+class Terminator(object):
     ''' Terminator elements (join, nextstate, stop) '''
-    def __init__(self, defName='Wait', defCoord=[0, 0, 100, 50]):
+    def __init__(self, defName='Wait'):
         ''' Initialize terminator attributes '''
         self.inputString = defName
-        # x y w h (relative and absolute)
-        self.coordinates = defCoord
-        self.absCoordinates = []
+        self.pos_x = None
+        self.pos_y = None
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         self.line = None
         self.charPositionInLine = None
         # one of 'next_state' 'join' 'stop'
@@ -254,18 +267,20 @@ class Terminator:
         return '{kind} {exp} ({l},{c}) at {x}, {y}'.format(
                 exp=self.inputString,
                 kind=self.kind.upper(), l=self.line, c=self.charPositionInLine,
-                x=self.coordinates[0], y=self.coordinates[1])
+                x=self.pos_x, y=self.pos_y)
 
 
-class Label:
+class Label(object):
     ''' AST Entry for a Label '''
     def __init__(self):
         ''' Initialize the label attributes '''
         # inputString holds the label name
         self.inputString = 'Here'
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         self.line = None
         self.charPositionInLine = None
         # optional hyperlink
@@ -279,7 +294,7 @@ class Label:
                 l=self.line, c=self.charPositionInLine)
 
 
-class Transition:
+class Transition(object):
     ''' AST Entry for a complete transition '''
     def __init__(self):
         ''' Initialize the transition attributes '''
@@ -289,14 +304,16 @@ class Transition:
         self.terminator = None
 
 
-class Input:
+class Input(object):
     ''' AST Entry for the INPUT symbol '''
     def __init__(self):
         ''' Initialize the Input attributes '''
         self.inputString = 'msgName'
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         self.line = None
         self.charPositionInLine = None
         # provided clause (not supported yet)
@@ -321,12 +338,15 @@ class Input:
                 l=self.line, c=self.charPositionInLine)
 
 
-class Start:
+class Start(object):
     ''' AST Entry for the START symbol '''
     def __init__(self):
         ''' Initialize the Start symbol attributes '''
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         # start transition is of type Transition
         self.transition = None
         # optional comment symbol
@@ -339,14 +359,17 @@ class Start:
         return 'START'
 
 
-class Comment:
+class Comment(object):
     ''' AST Entry for COMMENT symbols '''
     def __init__(self):
         ''' Comment symbol '''
         # inputString is the comment value itself
         self.inputString = 'Comment'
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         self.line = None
         self.charPositionInLine = None
         # optional hyperlink
@@ -358,7 +381,7 @@ class Comment:
                 l=self.line, c=self.charPositionInLine)
 
 
-class State:
+class State(object):
     ''' AST Entry for STATE symbols '''
     def __init__(self, defName='Wait'):
         ''' Used only for rendering backends - not for code generation '''
@@ -366,9 +389,11 @@ class State:
         self.inputString = defName
         self.line = None
         self.charPositionInLine = None
-        # x y w h (relative and absolute)
-        self.coordinates = [0, 0, 100, 50]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 100
+        self.height = 50
+        self.abs_x, self.abs_y = None, None
         # list of type Input
         self.inputs = []
         # optional comment symbol
@@ -380,10 +405,10 @@ class State:
         ''' Debug output for a STATE symbol '''
         return 'STATE {exp} ({l},{c}) at {x},{y}'.format(exp=self.inputString,
                 l=self.line, c=self.charPositionInLine,
-                x=self.coordinates[0], y=self.coordinates[1])
+                x=self.pos_x, y=self.pos_y)
 
 
-class TextArea:
+class TextArea(object):
     ''' AST Entry for text areas (containing declarations/comments) '''
     def __init__(self):
         ''' Text area (raw content for rendering only) '''
@@ -391,8 +416,11 @@ class TextArea:
         self.line = None
         self.charPositionInLine = None
         # Set default coordinates and width/height
-        self.coordinates = [0, 0, 170, 140]
-        self.absCoordinates = []
+        self.pos_x = 0
+        self.pos_y = 0
+        self.width = 170
+        self.height = 140
+        self.abs_x, self.abs_y = None, None
         # optional hyperlink
         self.hyperlink = None
 
@@ -402,7 +430,7 @@ class TextArea:
                 l=self.line, c=self.charPositionInLine)
 
 
-class Process:
+class Process(object):
     ''' SDL Process entry point '''
     def __init__(self):
         ''' Initializes the AST for a complete SDL process '''
