@@ -52,6 +52,9 @@ from ogAST import(Expression, Primary, Decision, Answer, Task, Transition,
 
 import samnmax
 
+import logging
+LOG = logging.getLogger(__name__)
+
 Kind = {PLUS: 'plus', ASTERISK: 'mul', DASH: 'minus', OR: 'or', AND: 'and',
         XOR: 'xor', EQ: 'eq', NEQ: 'neq', GT: 'gt', GE: 'ge', LT: 'lt',
         LE: 'le', DIV: 'div', MOD: 'mod', APPEND: 'append', IN: 'in',
@@ -60,11 +63,12 @@ Kind = {PLUS: 'plus', ASTERISK: 'mul', DASH: 'minus', OR: 'or', AND: 'and',
 # Insert current path in the search list for importing modules
 sys.path.insert(0, '.')
 
-errors = []
-warnings = []
+#errors = []
+#warnings = []
 dataView = None
 iv = None
 dv = None
+TOKENS = None
 
 # Code generator backends may need some intemediate variables to process
 # expressions. For convenience and to avoid multiple pass parsing, the parser
@@ -72,7 +76,7 @@ dv = None
 tmpVar = 0
 
 # Special SDL operators
-special_operators = {
+SPECIAL_OPERATORS = {
     'length': {'type': {'Kind': 'IntegerType'},
         'paramsInOrdered': ['seqof_ref'], 'paramsOutOrdered': [],
         'in': {'seqof_ref': {'type': '_SEQOF'}}},
@@ -88,7 +92,7 @@ special_operators = {
 
 def getInputString(root):
     ''' Return the input string of a tree node '''
-    return tokens.toString(root.getTokenStartIndex(),
+    return TOKENS.toString(root.getTokenStartIndex(),
             root.getTokenStopIndex())
 
 
@@ -107,18 +111,15 @@ def getStateList(processRoot):
     return set(stateList)
 
 
-def find_basic_type(aType):
-    ''' Return the ASN.1 basic type of aType '''
-    basic_type = aType
-    try:
-        while basic_type['Kind'] == 'ReferenceType':
-            # Find type with proper case in the data view
-            for t in dataView.viewkeys():
-                if t.lower() == basic_type['ReferencedTypeName'].lower():
-                    break
-            basic_type = dataView[t]['type']
-    except:
-        print '[ERROR] type', basic_type['ReferencedTypeName'], 'not found'
+def find_basic_type(a_type):
+    ''' Return the ASN.1 basic type of a_type '''
+    basic_type = a_type
+    while basic_type['Kind'] == 'ReferenceType':
+        # Find type with proper case in the data view
+        for typename in dataView.viewkeys():
+            if typename.lower() == basic_type['ReferencedTypeName'].lower():
+                basic_type = dataView[typename]['type']
+                break
     return basic_type
 
 
@@ -140,11 +141,11 @@ def check_and_fix_op_params(op_name, expr_list, process):
                 if key.lower() == op_name.lower():
                     break
             else:
-                for key, item in special_operators.viewitems():
+                for key, item in SPECIAL_OPERATORS.viewitems():
                     if key.lower() == op_name.lower():
                         break
                 else:
-                    print('[ERROR] Operator/output/procedure not found: '
+                    LOG.error('Operator/output/procedure not found: '
                             + op_name)
                     return False
     # (2) Build a list of all input and output params from the function spec
@@ -154,7 +155,7 @@ def check_and_fix_op_params(op_name, expr_list, process):
     # (3) Check that the number of parameters matches
     if(in_params is not None and out_params is not None and
             len(expr_list) != len(in_params + out_params)):
-        print('[ERROR] Wrong number of params in op call ' + op_name)
+        LOG.error('Wrong number of params in op call ' + op_name)
         return False
     # (4) Check each individual parameter type
     for idx, p in enumerate(expr_list):
@@ -179,11 +180,11 @@ def check_and_fix_op_params(op_name, expr_list, process):
         # If type is still unknown, then copy it from the specification:
         # (except for special operators, that have non-fixed types)
         if p.exprType.get('Kind') == 'UnknownType':
-            if paramType is not None and key not in special_operators.keys():
+            if paramType is not None and key not in SPECIAL_OPERATORS.keys():
                 p.exprType = {'Kind': 'ReferenceType',
                         'ReferencedTypeName': paramType}
             else:
-                print('[ERROR] Unable to determine param type: ' +
+                LOG.error('Unable to determine param type: ' +
                         p.inputString + '(in operator ' + op_name + ')')
                 return False
     return True
@@ -195,8 +196,8 @@ def isOfCompatibleType(primary, typeRef, process):
         is compatible with a given type
     '''
     actualType = find_basic_type(typeRef)
-    print "[DEBUG] checking if {value} is of type {typeref}".format(
-            value=primary.inputString, typeref=actualType['Kind'])
+    LOG.debug("[DEBUG] checking if {value} is of type {typeref}".format(
+            value=primary.inputString, typeref=actualType['Kind']))
 
     if (primary.kind == 'primaryId'
             and actualType['Kind'] == 'EnumeratedType'):
@@ -208,10 +209,10 @@ def isOfCompatibleType(primary, typeRef, process):
                 primary.kind = 'choiceDeterminant'
             else:
                 primary.kind = 'enumeratedValue'
-            print('... It is!')
+            LOG.debug('... It is!')
             return True
         else:
-            print('... It is not. value "', primary.primaryId[0],
+            LOG.debug('... It is not. value "', primary.primaryId[0],
                     '"not in this enumeration:',
                     actualType['EnumValues'].keys())
             return False
@@ -222,46 +223,46 @@ def isOfCompatibleType(primary, typeRef, process):
     elif (actualType['Kind'] in ('IntegerType', 'RealType') and
             (primary.kind == 'numericalValue' or primary.primType.get('Kind')
             == actualType['Kind'])):
-        print '... It is!'
+        LOG.debug('... It is!')
         return True
     elif (actualType['Kind'] == 'BooleanType' and
             primary.kind == 'booleanValue'):
-        print '... It is!'
+        LOG.debug('... It is!')
         return True
     elif (primary.kind == 'emptyString' and
             actualType['Kind'] == 'SequenceOfType'):
         if int(actualType['Min']) == 0:
-            print '...It is!'
+            LOG.debug('...It is!')
             return True
         else:
-            print ('... It is not (SEQUENCE OF has a minimum size == '
+            LOG.debug('... It is not (SEQUENCE OF has a minimum size == '
                     + actualType['Min'] + ')')
             return False
     elif (primary.kind == 'sequenceOf' and
             actualType['Kind'] == 'SequenceOfType'):
         if (len(primary.sequenceOf) < int(actualType['Min']) or
                 len(primary.sequenceOf) > int(actualType['Max'])):
-            print ('... It is not (', len(primary.sequenceOf),
+            LOG.debug('... It is not (', len(primary.sequenceOf),
                     'elems, while constraint is [',
                     actualType['Min'], '..', actualType['Max'], '])')
             return False
         for elem in primary.sequenceOf:
             if not isOfCompatibleType(elem, actualType['type'], process):
-                print '...It is not!'
+                LOG.debug('...It is not!')
                 return False
-        print '...SEQUENCE OF Check OK'
+        LOG.debug('...SEQUENCE OF Check OK')
         return True
     elif primary.kind == 'sequence' and actualType['Kind'] == 'SequenceType':
         userNbElem = len(primary.sequence.keys())
         typeNbElem = len(actualType['Children'].keys())
         if userNbElem != typeNbElem:
-            print ('... It is not '
+            LOG.debug('... It is not '
                    '(not the right number of fields in the sequence)')
             return False
         else:
             for field, fieldData in actualType['Children'].viewitems():
                 if field not in primary.sequence:
-                    print '... It is not (missing field ' + field + ')'
+                    LOG.debug('... It is not (missing field ' + field + ')')
                     return False
                 else:
                     # If the user field is a raw value
@@ -274,7 +275,7 @@ def isOfCompatibleType(primary, typeRef, process):
                         if not isOfCompatibleType(
                                 primary.sequence[field].var, fieldData['type'],
                                 process):
-                            print ('...it is not (field ' + field +
+                            LOG.debug('...it is not (field ' + field +
                                     ' is not of the proper type, i.e. ' + (
                                 fieldData['type'].get('ReferencedTypeName') or
                                 fieldData['type']['Kind']) + ')')
@@ -282,16 +283,16 @@ def isOfCompatibleType(primary, typeRef, process):
                     # Compare the types for semantic equivalence
                     elif not compare_types(
                         primary.sequence[field].exprType, fieldData['type']):
-                        print ('...it is not (field ' + field +
+                        LOG.debug('...it is not (field ' + field +
                             ' is not of the proper type, i.e. ' + (
                             fieldData['type'].get('ReferencedTypeName') or
                             fieldData['type']['Kind']) + ')')
                         return False
-            print '...It is!'
+            LOG.debug('...It is!')
             return True
     elif primary.kind == 'choiceItem' and actualType['Kind'] == 'ChoiceType':
         if primary.choiceItem['choice'] not in actualType['Children'].keys():
-            print '...It is not (inexistent choice)'
+            LOG.debug('...It is not (inexistent choice)')
             return False
         else:
             # compare primary.choiceItem['value']
@@ -306,7 +307,7 @@ def isOfCompatibleType(primary, typeRef, process):
                     ('UnknownType', 'IntegerType', 'RealType', 'BooleanType')):
                 if not isOfCompatibleType(value.var, typeOfChoiceField,
                         process):
-                    print('...it is not (field ' +
+                    LOG.debug('...it is not (field ' +
                             primary.choiceItem['choice'] +
                             ' is not of the proper type, i.e. ' +
                             (typeOfChoiceField.get('ReferencedTypeName') or
@@ -315,7 +316,7 @@ def isOfCompatibleType(primary, typeRef, process):
             # Compare the types for semantic equivalence:
             elif not compare_types(primary.choiceItem['value'].exprType,
                     typeOfChoiceField):
-                print('...it is not (field ' +
+                LOG.debug('...it is not (field ' +
                         primary.choiceItem['choice'] +
                         ' is not of the proper type, i.e. ' +
                         (typeOfChoiceField.get('ReferencedTypeName') or
@@ -324,10 +325,10 @@ def isOfCompatibleType(primary, typeRef, process):
             if value.kind == 'primary':
                 # Set the type of the choice field
                 value.var.primType = typeOfChoiceField
-        print '...It is!'
+        LOG.debug('...It is!')
         return True
     elif primary.kind == 'stringLiteral':
-        print 'Strings not fully supported yet'
+        LOG.warning('Strings not fully supported yet')
         return True  # Unsupported OCTET STRING
     elif primary.kind == 'ifThenElse':
         # check that IF expr returns BOOL, and that Then and Else expressions
@@ -336,7 +337,7 @@ def isOfCompatibleType(primary, typeRef, process):
         thenExpr = primary.ifThenElse['then']
         elseExpr = primary.ifThenElse['else']
         if ifExpr.exprType['Kind'] != 'BooleanType':
-            print '...No: IF expression does not return a boolean'
+            LOG.debug('...No: IF expression does not return a boolean')
             return False
         else:
             for expr in (thenExpr, elseExpr):
@@ -346,7 +347,7 @@ def isOfCompatibleType(primary, typeRef, process):
                         ('UnknownType', 'IntegerType',
                             'RealType', 'BooleanType')):
                     if not isOfCompatibleType(expr.var, typeRef, process):
-                        print('...it is not! (' +
+                        LOG.debug('...it is not! (' +
                             expr.var.inputString +
                             ' is not of the proper type, i.e. ' +
                             (typeRef.get('ReferencedTypeName') or
@@ -357,27 +358,27 @@ def isOfCompatibleType(primary, typeRef, process):
                         expr.exprType = typeRef
                 # compare the types for semantic equivalence:
                 elif not compare_types(expr.exprType, typeRef):
-                    print('...it is not (' + expr.inputString +
+                    LOG.debug('...it is not (' + expr.inputString +
                         ' is not of the proper type, i.e. ' +
                         (typeRef.get('ReferencedTypeName') or
                             typeRef['Kind']) + ')')
                     return False
-        print '...It is!'
+        LOG.debug('...It is!')
         return True
     elif (primary.kind == 'mantissaBaseExpFloat' and
         actualType['Kind'] == 'RealType'):
-        print ('..probably (it is a float but I did not check'
+        LOG.debug('..probably (it is a float but I did not check'
                'if values are compatible)')
         return True
     else:
-        print '...Cannot conclude. Assuming not.'
+        LOG.debug('...Cannot conclude. Assuming not.')
         return False
 
 
 def compare_types(typeA, typeB):
     ''' Compare two types, return True if they are semantically equivalent '''
     # Build the set of References for each type and look for an intersection
-    print '[DEBUG] compare_types', typeA, typeB
+    LOG.debug('Compare_types' + str(typeA) + str(typeB))
     if typeA == typeB:
         return True
     A = typeA
@@ -385,20 +386,20 @@ def compare_types(typeA, typeB):
     refsetA = []
     refsetB = []
     while A['Kind'] == 'ReferenceType':
-            refsetA.append(A['ReferencedTypeName'])
-            try:
-                A = dataView[A['ReferencedTypeName']]['type']
-            except:
-                # Type not in dataview is checked at DCL level
-                # no need to raise another error
-                # but return to avoid infinite loop
-                return False
+        refsetA.append(A['ReferencedTypeName'])
+        try:
+            A = dataView[A['ReferencedTypeName']]['type']
+        except:
+            # Type not in dataview is checked at DCL level
+            # no need to raise another error
+            # but return to avoid infinite loop
+            return False
     while B['Kind'] == 'ReferenceType':
-            refsetB.append(B['ReferencedTypeName'])
-            try:
-                B = dataView[B['ReferencedTypeName']]['type']
-            except:
-                return False
+        refsetB.append(B['ReferencedTypeName'])
+        try:
+            B = dataView[B['ReferencedTypeName']]['type']
+        except:
+            return False
     if set(refsetA).intersection(refsetB):
         # Types share a common name: they are identical
         # This cover structured types and enumerations
@@ -443,7 +444,7 @@ def findType(path, process):
     if not dataView:
         errors.append('Dataview is required to process types')
         return result, errors, warnings
-    #print '[DEBUG] Determining type of', path, '...',
+    LOG.debug('Determining type of ' + str(path) + '...')
     if path:
         # First, find the type of the main element
         # (variable, operator/procedure return type)
@@ -477,9 +478,9 @@ def findType(path, process):
                     else:
                         if main.lower() in ('true', 'false'):
                             result = {'Kind': 'BooleanType'}
-                        elif(main.lower() in special_operators
+                        elif(main.lower() in SPECIAL_OPERATORS
                                 and len(path) > 1):
-                            result = special_operators[main.lower()]['type']
+                            result = SPECIAL_OPERATORS[main.lower()]['type']
                             # Special operators require type elaboration
                             if main.lower() == 'present':
                                 # present(choiceType): must return an enum
@@ -536,7 +537,7 @@ def findType(path, process):
                                 ['ReferencedTypeName']]['type']
             # Sequence of
             elif current['Kind'] == 'SequenceOfType':
-                #print '[DEBUG] This should be an index:', elem
+                LOG.debug('This should be an index: ' + str(elem))
                 current = current['type']
                 if current['Kind'] == 'ReferenceType':
                     # Jump to the type of the Sequence of
@@ -660,9 +661,9 @@ class sdlScc_AST:
                 case_insensitive_ops = ([o.lower() for o in
                         self.process.operators] + [p.lower() for p in
                             self.process.procedures])
-                if(firstId.lower() in special_operators or
+                if(firstId.lower() in SPECIAL_OPERATORS or
                         firstId.lower() in case_insensitive_ops):
-                    print '[DEBUG] calling check_and_fix_op_params'
+                    LOG.debug('[DEBUG] calling check_and_fix_op_params')
                     # here we must check/set the type of each param
                     if not check_and_fix_op_params(
                             firstId.lower(), exprList, self.process):
@@ -818,7 +819,7 @@ class sdlScc_AST:
                 expr.right.var.kind = 'numericalValue'
 
             if expr.left.kind == 'primary':
-                print expr.left, expr.left.var.kind
+                LOG.debug(str(expr.left) + ' | ' + str(expr.left.var.kind))
 
             if (leftIsRaw and expr.left.exprType['Kind'] in
                     ('IntegerType', 'RealType')):
@@ -937,9 +938,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 userTextStartIndex = child.getTokenStopIndex() + 1
-                x, y, w, h = self.cif(child)
-                ta.coordinates = [x, y, w, h]
-                ta.absCoordinates = [x, y]
+                ta.pos_x, ta.pos_y, ta.width, ta.height = self.cif(child)
+                ta.abs_x = ta.pos_x
+                ta.abs_y = ta.pos_y
             elif child.type == TEXTAREA_CONTENT:
                 ta.line = child.getLine()
                 ta.charPositionInLine = child.getCharPositionInLine()
@@ -950,7 +951,7 @@ class sdlScc_AST:
                 map(warnings.append, warn)
             elif child.type == ENDTEXT:
                 userTextStopIndex = child.getTokenStartIndex() - 1
-                ta.inputString = tokens.toString(userTextStartIndex,
+                ta.inputString = TOKENS.toString(userTextStartIndex,
                         userTextStopIndex).strip()
             elif child.type == HYPERLINK:
                 ta.hyperlink = child.getChild(0).toString()[1:-1]
@@ -958,8 +959,8 @@ class sdlScc_AST:
                 warnings.append('Unsupported construct in text area, type: ' +
                         str(child.type))
         # Report errors with symbol coordinates
-        err = [[e, ta.absCoordinates] for e in errors]
-        warn = [[w, ta.absCoordinates] for w in warnings]
+        err = [[e, [ta.abs_x, ta.abs_y]] for e in errors]
+        warn = [[w, [ta.abs_x, ta.abs_y]] for w in warnings]
         return ta, err, warn
 
     def processDefinition(self, child):
@@ -1019,12 +1020,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                i.coordinates = [x, y, w, h]
-                if parent:
-                    i.absCoordinates = [a + b for a, b in
-                            zip(i.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                i.pos_x, i.pos_y, i.width, i.height = self.cif(child)
+                i.abs_x = i.pos_x + parent.abs_x if parent else 0
+                i.abs_y = i.pos_y + parent.abs_y if parent else 0
             elif child.type == INPUTLIST:
                 i.inputString = getInputString(child)
                 i.line = child.getLine()
@@ -1051,8 +1049,8 @@ class sdlScc_AST:
                                     p +
                                     ' WhateverType;" in a text area')
                 # Report errors with symbol coordinates
-                errors = [[e, i.absCoordinates] for e in errors]
-                warnings = [[w, i.absCoordinates] for w in warnings]
+                errors = [[e, [i.abs_x, i.abs_y]] for e in errors]
+                warnings = [[w, [i.abs_x, i.abs_y]] for w in warnings]
             elif child.type == ASTERISK:
                 # Asterisk means: all inputs not processed explicitely
                 # -> FIXME, below is incorrect
@@ -1092,14 +1090,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                s.coordinates = [x, y, w, h]
-                if parent:
-                    s.absCoordinates = [a + b for a, b in
-                            zip(s.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
-                else:
-                    s.absCoordinates = s.coordinates
+                s.pos_x, s.pos_y, s.width, s.height = self.cif(child)
+                s.abs_x = s.pos_x + parent.abs_x if parent else 0
+                s.abs_y = s.pos_y + parent.abs_y if parent else 0
             elif child.type == STATELIST:
                 # State name(s)
                 s.inputString = getInputString(child)
@@ -1157,9 +1150,8 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                s.coordinates = [x, y, w, h]
-                s.absCoordinates = [x, y]
+                s.pos_x, s.pos_y, s.width, s.height = self.cif(child)
+                s.abs_x, s.abs_y = s.pos_x, s.pos_y
             elif child.type == TRANSITION:
                 s.transition, err, warn = self.transition(child, parent=s)
                 map(errors.append, err)
@@ -1174,10 +1166,6 @@ class sdlScc_AST:
             else:
                 warnings.append('START unsupported child type: ' +
                         str(child.type))
-        # Report errors with symbol coordinates
-        # (removed: start symbol cannot have errors)
-        #err = [[e, s.absCoordinates] for e in errors]
-        #warn = [[w, s.absCoordinates] for w in warnings]
         return s, errors, warnings
 
     def end(self, root, parent=None):
@@ -1188,9 +1176,8 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                c.coordinates = [x, y, w, h]
-                c.absCoordinates = [x, y]
+                c.pos_x, c.pos_y, c.width, c.height = self.cif(child)
+                c.abs_x, c.abs_y = c.pos_x, c.pos_y
             elif child.type == StringLiteral:
                 c.inputString = child.toString()[1:-1]
             elif child.type == HYPERLINK:
@@ -1243,12 +1230,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                o.coordinates = [x, y, w, h]
-                if parent:
-                    o.absCoordinates = [a + b for a, b in
-                            zip(o.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                o.pos_x, o.pos_y, o.width, o.height = self.cif(child)
+                o.abs_x = o.pos_x + parent.abs_x if parent else 0
+                o.abs_y = o.pos_y + parent.abs_y if parent else 0
             elif child.type == OUTPUT_BODY:
                 o.inputString = getInputString(child)
                 o.line = child.getLine()
@@ -1265,8 +1249,8 @@ class sdlScc_AST:
                 warnings.append('Unsupported output child type: ' +
                         str(child.type))
         # Report errors with symbol coordinates
-        err = [[e, o.absCoordinates] for e in errors]
-        warn = [[w, o.absCoordinates] for w in warnings]
+        err = [[e, [o.abs_x, o.abs_y]] for e in errors]
+        warn = [[w, [o.abs_x, o.abs_y]] for w in warnings]
         return o, err, warn
 
     def alternative_part(self, root, parent):
@@ -1277,12 +1261,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                ans.coordinates = [x, y, w, h]
-                if parent:
-                    ans.absCoordinates = [a + b for a, b in
-                            zip(ans.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                ans.pos_x, ans.pos_y, ans.width, ans.height = self.cif(child)
+                ans.abs_x = ans.pos_x + parent.abs_x if parent else 0
+                ans.abs_y = ans.pos_y + parent.pos_y if parent else 0
             elif child.type == CLOSED_RANGE:
                 ans.kind = 'closed_range'
                 ans.closedRange = [float(child.getChild(0).toString()),
@@ -1319,8 +1300,8 @@ class sdlScc_AST:
                 ans.line = child.getLine()
                 ans.charPositionInLine = child.getCharPositionInLine()
                 # Report errors with symbol coordinates
-                errors = [[e, ans.absCoordinates] for e in errors]
-                warnings = [[w, ans.absCoordinates] for w in warnings]
+                errors = [[e, [ans.abs_x, ans.abs_y]] for e in errors]
+                warnings = [[w, [ans.abs_x, ans.abs_y]] for w in warnings]
         return ans, errors, warnings
 
     def decision(self, root, parent):
@@ -1334,19 +1315,18 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                dec.coordinates = [x, y, w, h]
-                if parent:
-                    dec.absCoordinates = [a + b for a, b in
-                            zip(dec.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                dec.pos_x, dec.pos_y, dec.width, dec.height = self.cif(child)
+                dec.abs_x = (dec.pos_x + parent.abs_x if parent else 0 +
+                            dec.width / 2)
+                dec.abs_y = (dec.pos_y + parent.abs_y if parent else 0 +
+                            dec.height / 2)
             elif child.type == QUESTION:
                 dec.kind = 'question'
                 decisionExpr, err, warn = self.expression(child.getChild(0))
                 for e in err:
-                    errors.append([e, dec.absCoordinates])
+                    errors.append([e, [dec.abs_x, dec.abs_y]])
                 for w in warn:
-                    warnings.append([w, dec.absCoordinates])
+                    warnings.append([w, [dec.abs_x, dec.abs_y]])
                 dec.question = decisionExpr
                 dec.inputString = dec.question.inputString
                 dec.line = dec.question.line
@@ -1387,7 +1367,7 @@ class sdlScc_AST:
                                 dec.question.inputString)
                     else:
                         ans.constant.var.primType = dec.question.exprType
-                        print '[DEBUG] ANSWER Kind:', ans.constant.var.kind
+                        LOG.debug('ANSWER Kind: ' + str(ans.constant.var.kind))
                 elif (ans.kind in ('constant', 'open_range')
                         and not compare_types(ans.constant.exprType,
                             dec.question.exprType)):
@@ -1402,24 +1382,22 @@ class sdlScc_AST:
                 a.inputString = 'ELSE'
                 for c in child.getChildren():
                     if c.type == CIF:
-                        x, y, w, h = self.cif(c)
-                        a.coordinates = [x, y, w, h]
-                        a.absCoordinates = [u + v for u, v in
-                                zip(a.coordinates[0:2],
-                                    dec.absCoordinates[0:2])]
+                        a.pos_x, a.pos_y, a.width, a.height = self.cif(c)
+                        a.abs_x = a.pos_x + dec.abs_x
+                        a.abs_y = a.pos_y + dec.abs_y
                     elif c.type == TRANSITION:
                         a.transition, err, warn = self.transition(c, parent=a)
                         for e in err:
-                            errors.append([e, a.absCoordinates])
+                            errors.append([e, [a.abs_x, a.abs_y]])
                         for w in warn:
-                            warnings.append([w, a.absCoordinates])
+                            warnings.append([w, [a.abs_x, a.abs_y]])
                     elif child.type == HYPERLINK:
                         a.hyperlink = child.getChild(0).toString()[1:-1]
                 a.kind = 'else'
                 dec.answers.append(a)
             else:
                 warnings.append(['Unsupported DECISION child type: ' +
-                    str(child.type), dec.absCoordinates])
+                    str(child.type), [dec.abs_x, dec.abs_y]])
         return dec, errors, warnings
 
     def terminator_statement(self, root, parent):
@@ -1429,12 +1407,9 @@ class sdlScc_AST:
         t = Terminator()
         for term in root.getChildren():
             if term.type == CIF:
-                x, y, w, h = self.cif(term)
-                t.coordinates = [x, y, w, h]
-                if parent:
-                    t.absCoordinates = [a + b for a, b in
-                            zip(t.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                t.pos_x, t.pos_y, t.width, t.height = self.cif(term)
+                t.abs_x = t.pos_x + parent.abs_x if parent else 0
+                t.abs_y = t.pos_y + parent.abs_y if parent else 0
             elif term.type == LABEL:
                 label, err, warn = self.label(term, parent=parent)
                 errors.extend(err)
@@ -1463,8 +1438,8 @@ class sdlScc_AST:
                 warnings.append('Unsupported terminator type: ' +
                         str(term.type))
         # Report errors with symbol coordinates
-        err = [[e, t.absCoordinates] for e in errors]
-        warn = [[w, t.absCoordinates] for w in warnings]
+        err = [[e, [t.abs_x, t.abs_y]] for e in errors]
+        warn = [[w, [t.abs_x, t.abs_y]] for w in warnings]
         return t, err, warn
 
     def transition(self, root, parent):
@@ -1616,12 +1591,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                t.coordinates = [x, y, w, h]
-                if parent:
-                    t.absCoordinates = [a + b for a, b in
-                            zip(t.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                t.pos_x, t.pos_y, t.width, t.height = self.cif(child)
+                t.abs_x = t.pos_x + parent.abs_x if parent else 0
+                t.abs_y = t.pos_y + parent.abs_y if parent else 0
             elif child.type == TASK_BODY:
                 t.inputString = getInputString(child)
                 t.line = child.getLine()
@@ -1637,8 +1609,8 @@ class sdlScc_AST:
                 warnings.append('Unsupported child type in task definition: ' +
                         str(child.type))
         # Report errors with symbol coordinates
-        err = [[e, t.absCoordinates] for e in errors]
-        warn = [[w, t.absCoordinates] for w in warnings]
+        err = [[e, [t.abs_x, t.abs_y]] for e in errors]
+        warn = [[w, [t.abs_x, t.abs_y]] for w in warnings]
         return t, err, warn
 
     def label(self, root, parent):
@@ -1649,12 +1621,9 @@ class sdlScc_AST:
         for child in root.getChildren():
             if child.type == CIF:
                 # Get symbol coordinates
-                x, y, w, h = self.cif(child)
-                t.coordinates = [x, y, w, h]
-                if parent:
-                    t.absCoordinates = [a + b for a, b in
-                            zip(t.coordinates[0:2],
-                                parent.absCoordinates[0:2])]
+                t.pos_x, t.pos_y, t.width, t.height = self.cif(child)
+                t.abs_x = t.pos_x + parent.abs_x if parent else 0
+                t.abs_y = t.pos_y + parent.abs_y if parent else 0
             elif child.type == ID:
                 t.inputString = getInputString(child)
                 t.line = child.getLine()
@@ -1666,8 +1635,8 @@ class sdlScc_AST:
                         'Unsupported child type in label definition: ' +
                         str(child.type))
         # Report errors with symbol coordinates
-        err = [[e, t.absCoordinates] for e in errors]
-        warn = [[w, t.absCoordinates] for w in warnings]
+        err = [[e, [t.abs_x, t.abs_y]] for e in errors]
+        warn = [[w, [t.abs_x, t.abs_y]] for w in warnings]
         return t, err, warn
 
 
@@ -1767,42 +1736,14 @@ def parserInitialize(fileName=None, string=None):
         try:
             char_stream = antlr3.ANTLRStringStream(string)
         except:
-            print '[ERROR] Impossible to initialize the parser'
+            LOG.error('Impossible to initialize the parser')
             return
     lexer = sdl92Lexer(char_stream)
-    global tokens
-    tokens = antlr3.CommonTokenStream(lexer)
-    parser = sdl92Parser(tokens)
+    global TOKENS
+    TOKENS = antlr3.CommonTokenStream(lexer)
+    parser = sdl92Parser(TOKENS)
     return parser
 
 
 if __name__ == '__main__':
-    if len(sys.argv) > 1:
-        print 'Loading file and parsing SDL process'
-        fileName = sys.argv[1]
-        process, warnings, error = parseProcessDefinition(fileName=fileName)
-        print('Parsing complete. Summary, found ' + str(len(warnings)) +
-                ' warnings and ' + str(len(errors)) + ' errors')
-        for w in warnings:
-            print w
-        for e in errors:
-            print w
-    else:
-        print 'Type an expression and Ctrl-D to finish'
-        char_stream = antlr3.ANTLRInputStream(sys.stdin)
-        lexer = sdl92Lexer(char_stream)
-        tokens = antlr3.CommonTokenStream(lexer)
-        parser = sdl92Parser(tokens)
-        r = parser.expression()
-        # Get the root of the AST (type is antlr3.tree.CommonTree)
-        root = r.tree
-        backend = sdlScc_AST()
-        expr, exprType = backend.expression(root)
-        print 'Expression type:', exprType
-
-    # root.getToken() returns CommonToken
-    #print root.toStringTree()
-    #children = root.getChildren()
-    #print root.getType(), children
-    #nodes = antlr3.tree.CommonTreeNodeStream(root)
-    #nodes.setTokenStream(tokens)
+    print 'This module is not callable'
