@@ -25,17 +25,15 @@ from genericSymbols import(
 
 from PySide.QtCore import Qt, QPoint, QRect
 from PySide.QtGui import(QPainterPath, QBrush, QColor, QPolygon,
-        QRadialGradient)
+        QRadialGradient, QPainter)
 
 import ogParser
 import ogAST
 
-#inputCompletionList = []
-#outputCompletionList = []
-#stateCompletionList = []
-#typesCompletionList = []
-#varCompletionList = []
-#procCompletionList = []
+#import traceback
+import logging
+
+LOG = logging.getLogger('sdlSymbols')
 
 
 class Input(HorizontalSymbol):
@@ -46,17 +44,16 @@ class Input(HorizontalSymbol):
     def __init__(self, parent=None, ast=None):
         ''' Create the INPUT symbol '''
         ast = ast or ogAST.Input()
-        coord_x, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         self.branchEntryPoint = None
         super(Input, self).__init__(polygon, parent, text=ast.inputString,
-                x=coord_x, y=coord_y, hyperlink=ast.hyperlink)
+                x=ast.pos_x, y=ast.pos_y, hyperlink=ast.hyperlink)
         gradient = QRadialGradient(50, 50, 50, 50, 50)
         gradient.setColorAt(0, QColor(255, 240, 170))
         gradient.setColorAt(1, Qt.white)
         self.setBrush(QBrush(gradient))
-        self.terminalSymbol = False
-        self.commonName = 'input_part'
+        self.terminal_symbol = False
+        self.common_name = 'input_part'
         self.parser = ogParser
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
@@ -67,19 +64,20 @@ class Input(HorizontalSymbol):
 
     def checkSyntax(self):
         ''' Redefined function, to check only the symbol, not recursively '''
-        _, syntaxErrors, __, ___, ____ = self.parser.parseSingleElement(
-                self.commonName, self.pr())
+        _, syntax_errors, __, ___, ____ = self.parser.parseSingleElement(
+                self.common_name, self.pr())
         try:
-            self.scene().reportErrors(syntaxErrors)
+            LOG.error('\n'.join(syntax_errors))
+            self.scene().raise_syntax_errors(syntax_errors)
         except:
-            print('[SYNTAX ERROR]', '\n'.join(syntaxErrors))
+            LOG.debug('raise_syntax_error raised an exception')
 
-    def insertSymbol(self, parent, x, y):
+    def insert_symbol(self, parent, x, y):
         ''' Insert Input symbol - propagate branch Entry point '''
         self.branchEntryPoint = parent.branchEntryPoint
-        super(Input, self).insertSymbol(parent, x, y)
+        super(Input, self).insert_symbol(parent, x, y)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Compute the polygon to fit in width, height '''
         polygon = QPolygon()
         polygon << QPoint(0, 0) \
@@ -90,10 +88,6 @@ class Input(HorizontalSymbol):
                 << QPoint(0, 0)
         return polygon
 
-#    def completionList(self):
-#        ''' Return the list of defined INPUTs for the autocompletion '''
-#        return inputCompletionList
-
     def pr(self):
         ''' Return the PR notation of the single INPUT sybol '''
         comment = repr(self.comment) if self.comment else ';'
@@ -109,10 +103,10 @@ class Input(HorizontalSymbol):
         ''' Return the complete Input branch in PR format '''
         result = [self.pr()]
         # Recursively return the complete branch below the INPUT
-        nextSymbol = self.nextAlignedSymbol()
-        while nextSymbol:
-            result.append(repr(nextSymbol))
-            nextSymbol = nextSymbol.nextAlignedSymbol()
+        next_symbol = self.nextAlignedSymbol()
+        while next_symbol:
+            result.append(repr(next_symbol))
+            next_symbol = next_symbol.nextAlignedSymbol()
         return '\n'.join(result)
 
 
@@ -123,13 +117,12 @@ class Output(VerticalSymbol):
 
     def __init__(self, parent=None, ast=None):
         ast = ast or ogAST.Output()
-        _, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(Output, self).__init__(polygon=polygon, parent=parent,
-                text=ast.inputString, y=coord_y, hyperlink=ast.hyperlink)
+                text=ast.inputString, y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setBrush(QBrush(QColor(255, 255, 202)))
-        self.terminalSymbol = False
-        self.commonName = 'output'
+        self.terminal_symbol = False
+        self.common_name = 'output'
         self.parser = ogParser
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
@@ -138,7 +131,7 @@ class Output(VerticalSymbol):
         ''' Return the text string as entered by the user '''
         return str(self.text)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Compute the polygon to fit in width, height '''
         polygon = QPolygon()
         polygon << QPoint(0, 0) \
@@ -149,10 +142,6 @@ class Output(VerticalSymbol):
                 << QPoint(0, 0)
         return polygon
 
-#    def completionList(self):
-#        ''' Return the list of defined OUTPUTs for the autocompletion '''
-#        return outputCompletionList
-
     def __repr__(self):
         ''' Return the text corresponding to the SDL PR notation '''
         comment = ';'
@@ -174,39 +163,31 @@ class Decision(VerticalSymbol):
 
     def __init__(self, parent=None, ast=None):
         ast = ast or ogAST.Decision()
-        _, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         # Define the point where all branches of the decision can join again
-        self.connectionPoint = QPoint(width / 2, height + 30)
+        self.connectionPoint = QPoint(ast.width / 2, ast.height + 30)
         super(Decision, self).__init__(polygon, parent, text=ast.inputString,
-                y=coord_y, hyperlink=ast.hyperlink)
+                y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setBrush(QColor(255, 255, 202))
         self.minDistanceToSymbolAbove = 0
-        # Can be a terminal symbol if all branches are terminated!
-        #self.terminalSymbol = False
-        self.commonName = 'decision'
+        self.common_name = 'decision'
         self.parser = ogParser
         self.text_alignment = Qt.AlignHCenter
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
 
     @property
-    def terminalSymbol(self):
+    def terminal_symbol(self):
         '''
             Compute dynamically if the item is terminal by checking
             if all its branches end with a terminator
         '''
         for branch in self.branches():
-            if not branch.lastBranchItem.terminalSymbol:
+            if not branch.lastBranchItem.terminal_symbol:
                 return False
         else:        
             return True
 
-#    @terminalSymbol.setter
-#    def terminalSymbol(self, value):
-#        ''' Discard the setter '''
-#        pass
-
     def branches(self):
         ''' Return the list of decision answers (as a generator) '''
         return (branch for branch in self.childSymbols()
@@ -219,13 +200,14 @@ class Decision(VerticalSymbol):
     def checkSyntax(self):
         ''' Redefined function, to check only the symbol, not recursively '''
         _, syntax_errors, __, ___, ____ = self.parser.parseSingleElement(
-                self.commonName, self.pr(recursive=False))
+                self.common_name, self.pr(recursive=False))
         try:
-            self.scene().reportErrors(syntax_errors)
+            LOG.error('\n'.join(syntax_errors))
+            self.scene().raise_syntax_errors(syntax_errors)
         except:
-            print('[SYNTAX ERROR]', '\n'.join(syntax_errors))
+            LOG.debug('raise_syntax_error raised an exception')
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Define polygon points to draw the symbol '''
         polygon = QPolygon()
         polygon << QPoint(width / 2, 0) \
@@ -235,64 +217,77 @@ class Decision(VerticalSymbol):
                 << QPoint(width / 2, 0)
         return polygon
 
-    def resizeItem(self, rect):
+    def resize_item(self, rect):
         ''' On resize event, make sure connection points are updated '''
-        super(Decision, self).resizeItem(rect)
-        self.updateConnectionPointPosition()
+        deltaX = (self.boundingRect().width() - rect.width()) / 2.0
+        deltaY = self.boundingRect().height() - rect.height()
+        self.prepareGeometryChange()
+        polygon = self.compute_polygon(rect.width(), rect.height())
+        self.setPolygon(polygon)
+        # Align children properly when resizing
+        for child in (c for c in self.childItems()
+                if not isinstance(c, Connection)):
+            # includes position of the text inside the box
+            child.moveBy(-deltaX, 0)
+        for child in self.childSymbols():
+            child.moveBy(0, -deltaY)
+        self.moveBy(deltaX, 0)
+        self.connectionPoint.setX(self.boundingRect().center().x())
+        self.connectionPoint.setY(self.connectionPoint.y() - deltaY)
+        self.update_connections()
+
+    def update_connections(self):
+        ''' Redefined - update arrows shape below connection point '''
+        super(Decision, self).update_connections()
+        for branch in self.branches():
+            for cnx in branch.lastBranchItem.connections():
+                cnx.reshape()
 
     def updateConnectionPointPosition(self):
         ''' Compute the joining point of decision branches '''
-        if not self.scene():
-            # Connection point update is only relevant for rendering
-            # (i.e. if symbol is in a scene) - ignore otherwise
-            return
         new_y = 0
-        new_x = self.boundingRect().width() / 2
+        new_x = self.boundingRect().width() / 2.0
         answers = False
         for branch in self.branches():
             answers = True
             last_cnx = None
             last = branch.lastBranchItem
-            # Coordinates of the last item of a branch
-            # in Decision item coordinates:
-            last_pos_y = self.mapFromScene(0, last.scenePos().y()).y()
             try:
                 # To compute the branch length, we must keep only the symbols,
-                # so we must remove the last connection
+                # so we must remove the last connection (if any)
                 last_cnx, = (c for c in last.childItems() if
                     isinstance(c, Connection) and not
-                    isinstance(c.child, Comment))
+                    isinstance(c.child, (Comment, HorizontalSymbol)))
                 last_cnx.setParentItem(None)
-            except:
+            except ValueError:
                 pass
-            if last.comment:
+            try:
                 # Disconnect the comment of the last item so that
                 # it's size is not taken into account
                 last.comment.setParentItem(None)
                 last.comment.connection.setParentItem(None)
-            # Update MP 30/01/13: Don't use QGraphicsItemGroup,
-            # it has bugs (with PySide 1.1.2)
-            # It puts unwanted focus on editable text of other items
-            # group = QGraphicsItemGroup(last.parentItem())
-            # group.addToGroup(last)
-            # groupHeight = group.boundingRect().height()
-            # self.scene().destroyItemGroup(group)
-            # branch_len = last_pos_y + groupHeight
+            except AttributeError:
+                pass
             branch_len = branch.y() + (
                     branch.boundingRect() |
                     branch.childrenBoundingRect()).height()
             try:
                 last_cnx.setParentItem(last)
-            except:
+            except AttributeError:
                 pass
-            if last.comment:
+            try:
                 # Reconnect the comment of the last item
                 last.comment.setParentItem(last)
                 last.comment.connection.setParentItem(last)
+            except AttributeError:
+                pass
             # If last item was a decision, use its connection point
             # position to get the length of the branch:
-            if isinstance(last, Decision):
-                branch_len = last_pos_y + last.connectionPoint.y()
+            try:
+                branch_len = (last.connectionPoint.y() +
+                        self.mapFromScene(0, last.scenePos().y()).y())
+            except AttributeError:
+                pass
             # Rounded with int() -> mandatory when view scale has changed
             new_y = int(max(new_y, branch_len))
         if not answers:
@@ -301,10 +296,16 @@ class Decision(VerticalSymbol):
         delta = new_y - self.connectionPoint.y()
         self.connectionPoint.setY(new_y)
         self.connectionPoint.setX(new_x)
-        child = filter(lambda c: not isinstance
-                (c, (DecisionAnswer, Comment)), self.childSymbols())
-        if child:
-            child[0].moveBy(0, delta)
+        #if self.scene():
+        #    point1 = self.mapToScene(0,0)
+        #    self.scene().addRect(point1.x(), point1.y(), new_x, new_y)
+        # Update position of the item below the connection point, if it moved
+        if delta != 0:
+            child = self.nextAlignedSymbol()
+            try:
+                child.moveBy(0, delta)
+            except AttributeError:
+                pass
 
     def pr(self, recursive=True):
         ''' Get PR notation of a decision (possibly recursively) '''
@@ -337,18 +338,17 @@ class DecisionAnswer(HorizontalSymbol):
 
     def __init__(self, parent=None, ast=None):
         ast = ast or ogAST.Answer()
-        coord_x, coord_y, width, height = ast.coordinates
-        self.terminalSymbol = False
+        self.terminal_symbol = False
         # lastBranchItem is used to compute branch length
         # for the connection point positionning
         self.lastBranchItem = self
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(DecisionAnswer, self).__init__(polygon, parent,
                 text=ast.inputString,
-                x=coord_x, y=coord_y, hyperlink=ast.hyperlink)
+                x=ast.pos_x, y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setPen(QColor(0, 0, 0, 0))
         self.branchEntryPoint = self
-        self.commonName = 'alternative_part'
+        self.common_name = 'alternative_part'
         self.parser = ogParser
 
     def __str__(self):
@@ -357,25 +357,26 @@ class DecisionAnswer(HorizontalSymbol):
 
     def checkSyntax(self):
         ''' Redefined function, to check only the symbol, not recursively '''
-        _, syntaxErrors, __, ___, ____ = self.parser.parseSingleElement(
-                self.commonName, self.pr(recursive=False))
+        _, syntax_errors, __, ___, ____ = self.parser.parseSingleElement(
+                self.common_name, self.pr(recursive=False))
         try:
-            self.scene().reportErrors(syntaxErrors)
+            LOG.error('\n'.join(syntax_errors))
+            self.scene().raise_syntax_errors(syntax_errors)
         except:
-            print('[SYNTAX ERROR]', '\n'.join(syntaxErrors))
+            LOG.debug('raise_syntax_error raised an exception')
 
-    def insertSymbol(self, parent, x, y):
+    def insert_symbol(self, parent, x, y):
         ''' ANSWER-specific insersion behaviour: link to connection point '''
         if not parent:
             return
-        super(DecisionAnswer, self).insertSymbol(parent, x, y)
+        super(DecisionAnswer, self).insert_symbol(parent, x, y)
         if not self.nextAlignedSymbol():
             # If inserting a new decision answer, link it
             # to the connection point
             self.connectionBelow = Connection(self, parent,
                     connectionPoint=True)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' ANSWER has round, disjoint sides - does not fit in a polygon '''
         bound = QRect(0, 0, width, height)
         polygon = QPolygon(bound)
@@ -384,6 +385,7 @@ class DecisionAnswer(HorizontalSymbol):
     def paint(self, painter, _, __):
         ''' Draw ANSWER shape within a polygon boundaries '''
         rect = self.boundingRect()
+        painter.setRenderHint(QPainter.Antialiasing, True)
         left = QRect(rect.x(), rect.y(), 35, rect.height())
         right = QRect(rect.width() - 35, rect.y(), 35, rect.height())
         painter.drawArc(left, 2000, 1760)
@@ -402,10 +404,10 @@ class DecisionAnswer(HorizontalSymbol):
                     w=int(self.boundingRect().width()),
                     h=int(self.boundingRect().height()))]
         if recursive:
-            nextSymbol = self.nextAlignedSymbol()
-            while nextSymbol:
-                result.append(repr(nextSymbol))
-                nextSymbol = nextSymbol.nextAlignedSymbol()
+            next_symbol = self.nextAlignedSymbol()
+            while next_symbol:
+                result.append(repr(next_symbol))
+                next_symbol = next_symbol.nextAlignedSymbol()
         return '\n'.join(result)
 
     def __repr__(self):
@@ -416,24 +418,35 @@ class DecisionAnswer(HorizontalSymbol):
 class Join(VerticalSymbol):
     ''' JOIN symbol (GOTO) '''
     allowed_followers = []
+    auto_expand = False
+    arrow_head = True
 
     def __init__(self, parent=None, ast=None):
-        ast = ast or ogAST.Terminator(defName='Goto', defCoord=[0, 0, 50, 50])
-        _, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        if not ast:
+            ast = ogAST.Terminator(defName='Goto')
+            ast.pos_y = 0
+            ast.width = 50
+            ast.height = 50
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(Join, self).__init__(polygon, parent, text=ast.inputString,
-                y=coord_y, hyperlink=ast.hyperlink)
+                y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setPen(QColor(0, 0, 0, 0))
-        self.terminalSymbol = True
-        self.arrowHead = True
-        self.commonName = 'terminator_statement'
+        self.terminal_symbol = True
+        self.common_name = 'terminator_statement'
         self.parser = ogParser
 
     def __str__(self):
         ''' Return the text string as entered by the user '''
         return str(self.text)
 
-    def computePolygon(self, width, height):
+    def resize_item(self, rect):
+        ''' Redefinition of the resize item (block is a square) '''
+        size = min(rect.width(), rect.height())
+        rect.setWidth(size)
+        rect.setHeight(size)
+        super(Join, self).resize_item(rect) 
+
+    def compute_polygon(self, width, height):
         ''' Define the bouding rectangle of the JOIN symbol '''
         circ = min(width, height)
         bound = QRect(0, 0, circ, circ)
@@ -443,6 +456,7 @@ class Join(VerticalSymbol):
     def paint(self, painter, _, __):
         ''' Draw the JOIN symbol - a circle '''
         rect = self.boundingRect()
+        painter.setRenderHint(QPainter.Antialiasing, True)
         painter.setPen(Qt.blue)
         painter.drawEllipse(rect)
         super(Join, self).paint(painter, _, __)
@@ -465,21 +479,20 @@ class Label(VerticalSymbol):
 
     def __init__(self, parent=None, ast=None):
         ast = ast or ogAST.Label()
-        _, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(Label, self).__init__(polygon, parent, text=ast.inputString,
-                y=coord_y, hyperlink=ast.hyperlink)
+                y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setPen(QColor(0, 0, 0, 0))
-        self.terminalSymbol = False
+        self.terminal_symbol = False
         self.textbox_alignment = Qt.AlignLeft | Qt.AlignTop
-        self.commonName = 'label'
+        self.common_name = 'label'
         self.parser = ogParser
 
     def __str__(self):
         ''' Return the text string as entered by the user '''
         return str(self.text)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Define the boundaries of the LABEL symbol '''
         return QPolygon(QRect(0, 0, width, height))
 
@@ -511,57 +524,54 @@ class Label(VerticalSymbol):
                     h=int(self.boundingRect().height())))
 
 
-class Condition(VerticalSymbol):
-    ''' Condition is below an INPUT - It's not a continuous signal '''
-    # NOT SUPPORTED (Makes no sense in code generation) '''
-    def __init__(self, parent=None, text='Provided', y=None,
-            w=None, h=None, hyperlink=None):
-        w = w or 100
-        h = h or 50
-        polygon = self.computePolygon(w, h)
-        super(Condition, self).__init__(polygon, parent, text=text,
-                y=y, hyperlink=hyperlink)
-        self.setPen(QColor(0, 0, 0, 0))
-        self.terminalSymbol = False
-        self.allowed_followers = [Task, ProcedureCall, Output, Decision,
-                Join, Label, State]
-        self.commonName = 'condition'
-        self.parser = ogParser
+#class Condition(VerticalSymbol):
+#    ''' Condition is below an INPUT - It's not a continuous signal '''
+#    # NOT SUPPORTED (Makes no sense in code generation) '''
+#    def __init__(self, parent=None, text='Provided', y=None,
+#            w=None, h=None, hyperlink=None):
+#        w = w or 100
+#        h = h or 50
+#        polygon = self.compute_polygon(w, h)
+#        super(Condition, self).__init__(polygon, parent, text=text,
+#                y=y, hyperlink=hyperlink)
+#        self.setPen(QColor(0, 0, 0, 0))
+#        self.terminal_symbol = False
+#        self.allowed_followers = [Task, ProcedureCall, Output, Decision,
+#                Join, Label, State]
+#        self.common_name = 'condition'
+#        self.parser = ogParser
+#
+#    def __str__(self):
+#        return str(self.text)
+#
+#    def compute_polygon(self, width, height):
+#        bound = QRect(0, 0, width, height)
+#        polygon = QPolygon(bound)
+#        return polygon
+#
+#    def paint(self, painter, _, __):
+#        rect = self.boundingRect()
+#        painter.drawLines([QPoint(10, 0), QPoint(0, rect.height() / 2),
+#                           QPoint(0, rect.height() / 2),
+#                           QPoint(10, rect.height())])
+#        painter.drawLines([QPoint(rect.width() - 10, 0),
+#                           QPoint(rect.width(), rect.height() / 2),
+#                           QPoint(rect.width(), rect.height() / 2),
+#                          QPoint(rect.width() - 10, rect.height())])
+#       super(Condition, self).paint(self, painter, _, __)
 
-    def __str__(self):
-        return str(self.text)
-
-    def computePolygon(self, width, height):
-        bound = QRect(0, 0, width, height)
-        polygon = QPolygon(bound)
-        return polygon
-
-    def paint(self, painter, _, __):
-        #font = QFont()
-        #font.setPixelSize(40)
-        #painter.setFont(font)
-        rect = self.boundingRect()
-        painter.drawLines([QPoint(10, 0), QPoint(0, rect.height() / 2),
-                           QPoint(0, rect.height() / 2),
-                           QPoint(10, rect.height())])
-        painter.drawLines([QPoint(rect.width() - 10, 0),
-                           QPoint(rect.width(), rect.height() / 2),
-                           QPoint(rect.width(), rect.height() / 2),
-                           QPoint(rect.width() - 10, rect.height())])
-        super(Condition, self).paint(self, painter, _, __)
-
-    def __repr__(self):
-        ''' Return the text corresponding to the SDL PR notation '''
-        comment = ';'
-        if self.comment:
-            comment = repr(self.comment)
-        return ('/* CIF PROVIDED ({x}, {y}), ({w}, {h}) */\n'
-                '{hlink}'
-                'PROVIDED {p}{comment}'.format(p=str(self.text),
-                    hlink=repr(self.text),
-                    x=int(self.x()), y=int(self.y()),
-                    w=int(self.boundingRect().width()),
-                    h=int(self.boundingRect().height()), comment=comment))
+#    def __repr__(self):
+#        ''' Return the text corresponding to the SDL PR notation '''
+#        comment = ';'
+#        if self.comment:
+#            comment = repr(self.comment)
+#        return ('/* CIF PROVIDED ({x}, {y}), ({w}, {h}) */\n'
+#                '{hlink}'
+#                'PROVIDED {p}{comment}'.format(p=str(self.text),
+#                    hlink=repr(self.text),
+#                    x=int(self.x()), y=int(self.y()),
+#                    w=int(self.boundingRect().width()),
+#                    h=int(self.boundingRect().height()), comment=comment))
 
 
 class Task(VerticalSymbol):
@@ -572,13 +582,12 @@ class Task(VerticalSymbol):
     def __init__(self, parent=None, ast=None):
         ''' Initializes the TASK symbol '''
         ast = ast or ogAST.Task()
-        _, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(Task, self).__init__(polygon, parent, text=ast.inputString,
-                y=coord_y, hyperlink=ast.hyperlink)
+                y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setBrush(QBrush(QColor(255, 255, 202)))
-        self.terminalSymbol = False
-        self.commonName = 'task'
+        self.terminal_symbol = False
+        self.common_name = 'task'
         self.parser = ogParser
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
@@ -587,7 +596,7 @@ class Task(VerticalSymbol):
         ''' Return the text string as entered by the user '''
         return str(self.text)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Compute the polygon to fit in width, height '''
         polygon = QPolygon()
         polygon << QPoint(0, 0) \
@@ -597,10 +606,6 @@ class Task(VerticalSymbol):
                 << QPoint(0, 0)
         return polygon
 
-#    def completionList(self):
-#        ''' Return the list of defined INPUTs for the autocompletion '''
-#        return varCompletionList
-
     def __repr__(self):
         ''' Return the text corresponding to the SDL PR notation '''
         comment = ';'
@@ -622,13 +627,12 @@ class ProcedureCall(VerticalSymbol):
 
     def __init__(self, parent=None, ast=None):
         ast = ast or ogAST.Output(defName='callMe')
-        _, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(ProcedureCall, self).__init__(polygon, parent,
-                text=ast.inputString, y=coord_y, hyperlink=ast.hyperlink)
+                text=ast.inputString, y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setBrush(QBrush(QColor(255, 255, 202)))
-        self.terminalSymbol = False
-        self.commonName = 'procedure_call'
+        self.terminal_symbol = False
+        self.common_name = 'procedure_call'
         self.parser = ogParser
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
@@ -637,7 +641,7 @@ class ProcedureCall(VerticalSymbol):
         ''' Return the text string as entered by the user '''
         return str(self.text)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Compute the polygon to fit in width, height '''
         polygon = QPolygon()
         polygon << QPoint(0, 0) \
@@ -651,10 +655,6 @@ class ProcedureCall(VerticalSymbol):
                 << QPoint(7, 0)
         return polygon
 
-#    def completionList(self):
-#        ''' Return the list of defined procedures for the autocompletion '''
-#        return procCompletionList
-
     def __repr__(self):
         ''' Return the text corresponding to the SDL PR notation '''
         comment = ';'
@@ -676,26 +676,25 @@ class TextSymbol(HorizontalSymbol):
     def __init__(self, ast=None):
         ''' Create a Text Symbol '''
         ast = ast or ogAST.TextArea()
-        coord_x, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(TextSymbol, self).__init__(polygon, parent=None,
                 text=ast.inputString,
-                x=coord_x, y=coord_y, hyperlink=ast.hyperlink)
+                x=ast.pos_x, y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setBrush(QBrush(QColor(249, 249, 249)))
-        self.terminalSymbol = False
-        self.setPos(coord_x, coord_y)
+        self.terminal_symbol = False
+        self.setPos(ast.pos_x, ast.pos_y)
         # Disable hyperlinks for Text symbols
         self._no_hyperlink = True
         # Text is not centered in the box - change default alignment:
         self.textbox_alignment = Qt.AlignLeft | Qt.AlignTop
-        self.commonName = 'text_area'
+        self.common_name = 'text_area'
         self.parser = ogParser
 
     def __str__(self):
         ''' Return the text string as entered by the user '''
         return str(self.text)
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Define the polygon of the text symbol '''
         polygon = QPolygon()
         polygon << QPoint(width - 10, 0) \
@@ -708,14 +707,10 @@ class TextSymbol(HorizontalSymbol):
                 << QPoint(width, 10)
         return polygon
 
-#    def completionList(self):
-#        ''' Return the list of defined ASN.1 datatypes for autocompletion '''
-#        return typesCompletionList
-
-    def resizeItem(self, rect):
+    def resize_item(self, rect):
         ''' Text Symbol only resizes in one direction '''
         self.prepareGeometryChange()
-        polygon = self.computePolygon(rect.width(), rect.height())
+        polygon = self.compute_polygon(rect.width(), rect.height())
         self.setPolygon(polygon)
 
     def __repr__(self):
@@ -733,28 +728,27 @@ class TextSymbol(HorizontalSymbol):
 class State(VerticalSymbol):
     ''' SDL STATE Symbol '''
     allowed_followers = ['Input', 'Comment']
+    arrow_head = True
 
     def __init__(self, parent=None, ast=None):
         ast = ast or ogAST.State()
         # Note: ast coordinates are in scene coordinates
-        coord_x, coord_y, width, height = ast.coordinates
-        polygon = self.computePolygon(width, height)
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(State, self).__init__(polygon=polygon, parent=parent,
-                text=ast.inputString, y=coord_y, hyperlink=ast.hyperlink)
+                text=ast.inputString, y=ast.pos_y, hyperlink=ast.hyperlink)
         self.setBrush(QBrush(QColor(255, 228, 213)))
-        self.arrowHead = True
-        self.terminalSymbol = True
+        self.terminal_symbol = True
         if parent:
-            # Change to parent coordinates
-            self.setPos(parent.mapFromScene(coord_x, coord_y))
-            self.setPos(self.mapFromScene(coord_x, coord_y))
-            #print 'Set nextState pos to', self.pos()
-            #print coord_x, coord_y, self.mapFromScene(coord_x, coord_y)
+            try:
+                # Map AST scene coordinates to get actual position
+                self.setPos(self.pos() + self.mapFromScene(ast.pos_x, ast.pos_y))
+            except TypeError:
+                self.updatePosition()
         else:
             # Use scene coordinates to position
-            self.setPos(coord_x, coord_y)
+            self.setPos(ast.pos_x, ast.pos_y)
         self.parser = ogParser
-        self.commonName = 'terminator_statement'
+        self.common_name = 'terminator_statement'
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
 
@@ -767,22 +761,19 @@ class State(VerticalSymbol):
         if self.hasParent:
             super(State, self).checkSyntax()
         else:
-            _, syntaxErrors, __, ___, ____ = self.parser.parseSingleElement(
+            _, syntax_errors, __, ___, ____ = self.parser.parseSingleElement(
                     'state', self.parseGR(recursive=False))
             try:
-                self.scene().reportErrors(syntaxErrors)
+                LOG.error('\n'.join(syntax_errors))
+                self.scene().raise_syntax_errors(syntax_errors)
             except:
-                print('[SYNTAX ERROR]', '\n'.join(syntaxErrors))
+                LOG.debug('raise_syntax_error raised an exception')
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Compute the polygon to fit in width, height '''
-        statePath = QPainterPath()
-        statePath.addRoundedRect(0, 0, width, height, 15, 50)
-        return statePath.toFillPolygon()
-
- #   def completionList(self):
- #       ''' Return the list of defined STATEs for the autocompletion '''
- #       return stateCompletionList
+        state_path = QPainterPath()
+        state_path.addRoundedRect(0, 0, width, height, 15, 50)
+        return state_path.toFillPolygon()
 
     def get_ast(self):
         ''' Redefinition of the get_ast function for the state '''
@@ -845,16 +836,15 @@ class Start(HorizontalSymbol):
 
     def __init__(self, ast=None):
         ast = ast or ogAST.Start()
-        coord_x, coord_y, width, height = ast.coordinates
-        self.terminalSymbol = False
-        polygon = self.computePolygon(width, height)
+        self.terminal_symbol = False
+        polygon = self.compute_polygon(ast.width, ast.height)
         super(Start, self).__init__(polygon, parent=None, text='',
-                x=coord_x, y=coord_y,
+                x=ast.pos_x, y=ast.pos_y,
                 hyperlink=ast.hyperlink)
         self.setBrush(QBrush(QColor(255, 228, 213)))
         # No hyperlink for START symbol because it has no text
         self._no_hyperlink = True
-        self.commonName = 'start'
+        self.common_name = 'start'
         self.parser = ogParser
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
@@ -863,7 +853,7 @@ class Start(HorizontalSymbol):
         ''' User cannot enter text in the START symbol - Return dummy text '''
         return 'START'
 
-    def computePolygon(self, width, height):
+    def compute_polygon(self, width, height):
         ''' Compute the polygon to fit in width, height '''
         path = QPainterPath()
         path.addRoundedRect(0, 0, width, height, 25, 25)
@@ -880,8 +870,8 @@ class Start(HorizontalSymbol):
                     w=int(self.boundingRect().width()),
                     h=int(self.boundingRect().height()), comment=comment))
         # Recursively return the complete branch below the start symbol
-        nextSymbol = self.nextAlignedSymbol()
-        while nextSymbol:
-            result.append(repr(nextSymbol))
-            nextSymbol = nextSymbol.nextAlignedSymbol()
+        next_symbol = self.nextAlignedSymbol()
+        while next_symbol:
+            result.append(repr(next_symbol))
+            next_symbol = next_symbol.nextAlignedSymbol()
         return '\n'.join(result)
