@@ -20,6 +20,9 @@
 
 from PySide.QtGui import QUndoCommand
 
+import logging
+LOG = logging.getLogger(__name__)
+
 
 class ReplaceText(QUndoCommand):
     ''' Undo/Redo command for updating the text in a symbol '''
@@ -47,10 +50,14 @@ class ResizeSymbol(QUndoCommand):
         self.new_rect = new_rect
 
     def undo(self):
-        self.symbol.resizeItem(self.old_rect)
+        self.symbol.resize_item(self.old_rect)
+        # Update grabber size
+        self.symbol.grabber.display()
 
     def redo(self):
-        self.symbol.resizeItem(self.new_rect)
+        self.symbol.resize_item(self.new_rect)
+        # Update grabber size
+        self.symbol.grabber.display()
 
 
 class InsertSymbol(QUndoCommand):
@@ -66,12 +73,13 @@ class InsertSymbol(QUndoCommand):
     def undo(self):
         self.pos_x = self.item.x()
         self.pos_y = self.item.y()
-        self.item.deleteSymbol()
+        self.item.delete_symbol()
 
     def redo(self):
         if self.item not in self.scene.items():
             self.scene.addItem(self.item)
-        self.item.insertSymbol(self.parent, x=self.pos_x, y=self.pos_y)
+        self.item.insert_symbol(self.parent, self.pos_x, self.pos_y)
+        self.item.grabber.display()
         self.scene.refresh()
 
 
@@ -86,7 +94,7 @@ class DeleteSymbol(QUndoCommand):
         self.pos_y = 0
 
     def undo(self):
-        self.item.insertSymbol(self.parent, self.pos_x, self.pos_y)
+        self.item.insert_symbol(self.parent, self.pos_x, self.pos_y)
         if self.item not in self.scene.items():
             self.scene.addItem(self.item)
         self.scene.refresh()
@@ -94,7 +102,7 @@ class DeleteSymbol(QUndoCommand):
     def redo(self):
         self.pos_x = self.item.x()
         self.pos_y = self.item.y()
-        self.item.deleteSymbol()
+        self.item.delete_symbol()
         self.scene.refresh()
 
 
@@ -110,25 +118,15 @@ class MoveSymbol(QUndoCommand):
     def undo(self):
         ''' Undo a symbol move '''
         self.symbol.setPos(self.old_pos)
-        if hasattr(self.symbol, 'decisionParent'):
+        try:
             self.symbol.decisionParent.updateConnectionPointPosition()
-        elif hasattr(self.symbol, 'onTheRight'):
-            # If comment symbol, correctly flip it depending on its position
-            if(self.symbol.x() <
-                    self.symbol.parentItem().boundingRect().width() + 5):
-                self.symbol.onTheRight = False
-            else:
-                self.symbol.onTheRight = True
+        except AttributeError:
+            pass
 
     def redo(self):
         ''' Apply a symbol move '''
         self.symbol.setPos(self.new_pos)
-        if hasattr(self.symbol, 'decisionParent'):
+        try:
             self.symbol.decisionParent.updateConnectionPointPosition()
-        elif hasattr(self.symbol, 'onTheRight'):
-            # If comment symbol, correctly flip it depending on its position
-            if(self.symbol.x() <
-                    self.symbol.parentItem().boundingRect().width() + 5):
-                self.symbol.onTheRight = False
-            else:
-                self.symbol.onTheRight = True
+        except AttributeError:
+            pass
